import {
  Entity,
  Column,
  ManyToOne,
  ManyToMany,
  JoinTable,
  OneToMany,
} from 'typeorm';
import { SpaceModelEntity } from './space-model.entity';
import { NewTagEntity } from '../../tag/entities/tag.entity';
import { ProductEntity } from '../../product/entities/product.entity';
import { SpaceProductAllocationEntity } from '../../space/entities/space-product-allocation.entity';
import { AbstractEntity } from '../../abstract/entities/abstract.entity';

@Entity({ name: 'space_model_product_allocation' })
export class SpaceModelProductAllocationEntity extends AbstractEntity<SpaceModelProductAllocationEntity> {
  @Column({
    type: 'uuid',
    default: () => 'gen_random_uuid()',
    nullable: false,
  })
  public uuid: string;

  @ManyToOne(
    () => SpaceModelEntity,
    (spaceModel) => spaceModel.productAllocations,
    { nullable: false, onDelete: 'CASCADE' },
  )
  public spaceModel: SpaceModelEntity;

  @ManyToOne(() => ProductEntity, { nullable: false, onDelete: 'CASCADE' })
  public product: ProductEntity;

  @ManyToMany(() => NewTagEntity, { cascade: true, onDelete: 'CASCADE' })
  @JoinTable({ name: 'space_model_product_tags' })
  public tags: NewTagEntity[];

  @OneToMany(
    () => SpaceProductAllocationEntity,
    (allocation) => allocation.inheritedFromModel,
    {
      cascade: true,
    },
  )
  public inheritedSpaceAllocations: SpaceProductAllocationEntity[];

  constructor(partial: Partial<SpaceModelProductAllocationEntity>) {
    super();
    Object.assign(this, partial);
  }
}
