import { AbstractEntity } from '@app/common/modules/abstract/entities/abstract.entity';
import { Column, Entity, ManyToOne, OneToMany } from 'typeorm';
import { SubSpaceModelDto } from '../../dtos';
import { SpaceModelEntity } from '../space-model.entity';
import { TagModel } from '../tag-model.entity';
import { SubspaceModelProductAllocationEntity } from './subspace-model-product-allocation.entity';
import { SubspaceEntity } from '@app/common/modules/space/entities/subspace/subspace.entity';

@Entity({ name: 'subspace-model' })
export class SubspaceModelEntity extends AbstractEntity<SubSpaceModelDto> {
  @Column({
    type: 'uuid',
    default: () => 'gen_random_uuid()',
    nullable: false,
  })
  public uuid: string;

  @Column({
    nullable: false,
  })
  public subspaceName: string;

  @ManyToOne(
    () => SpaceModelEntity,
    (spaceModel) => spaceModel.subspaceModels,
    {
      nullable: false,
      onDelete: 'CASCADE',
    },
  )
  public spaceModel: SpaceModelEntity;

  @OneToMany(() => SubspaceEntity, (subspace) => subspace.subSpaceModel, {
    cascade: true,
  })
  public subspace: SubspaceEntity[];

  @Column({
    nullable: false,
    default: false,
  })
  public disabled: boolean;

  @OneToMany(() => TagModel, (tag) => tag.subspaceModel)
  tags: TagModel[];

  @OneToMany(
    () => SubspaceModelProductAllocationEntity,
    (allocation) => allocation.subspaceModel,
    { cascade: true },
  )
  public productAllocations: SubspaceModelProductAllocationEntity[];
}
