import {
  Entity,
  Column,
  ManyToOne,
  ManyToMany,
  JoinTable,
  Unique,
} from 'typeorm';
import { SubspaceEntity } from './subspace.entity';
import { ProductEntity } from '@app/common/modules/product/entities';
import { SubspaceModelProductAllocationEntity } from '@app/common/modules/space-model';
import { NewTagEntity } from '@app/common/modules/tag/entities/tag.entity';
import { AbstractEntity } from '@app/common/modules/abstract/entities/abstract.entity';
import { SubspaceProductAllocationDto } from '../../dtos/subspace-product-allocation.dto';

@Entity({ name: 'subspace_product_allocation' })
// @Unique(['subspace', 'product'])
export class SubspaceProductAllocationEntity extends AbstractEntity<SubspaceProductAllocationDto> {
  @Column({
    type: 'uuid',
    default: () => 'gen_random_uuid()',
    nullable: false,
  })
  public uuid: string;

  @ManyToOne(() => SubspaceEntity, (subspace) => subspace.productAllocations, {
    nullable: false,
    onDelete: 'CASCADE',
  })
  public subspace: SubspaceEntity;

  @ManyToOne(() => SubspaceModelProductAllocationEntity, {
    nullable: true,
    onDelete: 'SET NULL',
  })
  public inheritedFromModel?: SubspaceModelProductAllocationEntity;

  @ManyToOne(() => ProductEntity, { nullable: false, onDelete: 'CASCADE' })
  public product: ProductEntity;

  @ManyToMany(() => NewTagEntity)
  @JoinTable({ name: 'subspace_product_tags' })
  public tags: NewTagEntity[];

  constructor(partial: Partial<SubspaceProductAllocationEntity>) {
    super();
    Object.assign(this, partial);
  }
}
