import { Entity, Column, ManyToOne, JoinColumn, OneToOne } from 'typeorm';
import { AbstractEntity } from '../../abstract/entities/abstract.entity';
import { ProductEntity } from '../../product/entities';
import { TagDto } from '../dtos';
import { TagModel } from '../../space-model/entities/tag-model.entity';
import { DeviceEntity } from '../../device/entities';
import { SubspaceEntity } from './subspace/subspace.entity';

@Entity({ name: 'tag' })
export class TagEntity extends AbstractEntity<TagDto> {
  @Column({ type: 'varchar', length: 255, nullable: true })
  tag: string;

  @ManyToOne(() => TagModel, (model) => model.tags, {
    nullable: true,
  })
  model: TagModel;

  @ManyToOne(() => ProductEntity, (product) => product.tags, {
    nullable: false,
  })
  product: ProductEntity;

  @ManyToOne(() => SubspaceEntity, (subspace) => subspace.tags, {
    nullable: true,
  })
  @JoinColumn({ name: 'subspace_id' })
  subspace: SubspaceEntity;

  @Column({
    nullable: false,
    default: false,
  })
  public disabled: boolean;

  @OneToOne(() => DeviceEntity, (device) => device.tag, {
    nullable: true,
  })
  @JoinColumn({ name: 'device_id' })
  device: DeviceEntity;
}
