import { Module } from '@nestjs/common';
import { InviteUserService } from './services/invite-user.service';
import { InviteUserController } from './controllers/invite-user.controller';
import { ConfigModule } from '@nestjs/config';

import {
  UserRepository,
  UserSpaceRepository,
} from '@app/common/modules/user/repositories';
import { InviteUserRepositoryModule } from '@app/common/modules/Invite-user/Invite-user.repository.module';
import {
  InviteUserRepository,
  InviteUserSpaceRepository,
} from '@app/common/modules/Invite-user/repositiories';
import { EmailService } from '@app/common/util/email.service';
import {
  SpaceLinkService,
  SpaceService,
  SpaceUserService,
  SubspaceDeviceService,
  SubSpaceService,
  ValidationService,
} from 'src/space/services';
import { CommunityService } from 'src/community/services';
import {
  InviteSpaceRepository,
  SpaceLinkRepository,
  SpaceProductAllocationRepository,
  SpaceRepository,
  TagRepository,
} from '@app/common/modules/space';
import { SpaceModelRepository } from '@app/common/modules/space-model';
import { CommunityRepository } from '@app/common/modules/community/repositories';
import { ProjectRepository } from '@app/common/modules/project/repositiories';
import { TuyaService } from '@app/common/integrations/tuya/services/tuya.service';
import { UserService, UserSpaceService } from 'src/users/services';
import { UserDevicePermissionService } from 'src/user-device-permission/services';
import {
  DeviceRepository,
  DeviceUserPermissionRepository,
} from '@app/common/modules/device/repositories';
import { PermissionTypeRepository } from '@app/common/modules/permission/repositories';
import { ProjectUserService } from 'src/project/services/project-user.service';
import { RoleTypeRepository } from '@app/common/modules/role-type/repositories';
import { RegionRepository } from '@app/common/modules/region/repositories';
import { TimeZoneRepository } from '@app/common/modules/timezone/repositories';
import { CommunityModule } from 'src/community/community.module';
import { TagService as NewTagService } from 'src/tags/services';
import { TagService } from 'src/space/services/tag';
import {
  SpaceModelService,
  SubSpaceModelService,
} from 'src/space-model/services';
import { SpaceProductAllocationService } from 'src/space/services/space-product-allocation.service';
import {
  SubspaceProductAllocationRepository,
  SubspaceRepository,
} from '@app/common/modules/space/repositories/subspace.repository';
import { SubspaceProductAllocationService } from 'src/space/services/subspace/subspace-product-allocation.service';
import {
  SpaceModelProductAllocationRepoitory,
  SubspaceModelProductAllocationRepoitory,
  SubspaceModelRepository,
} from '@app/common/modules/space-model';
import { NewTagRepository } from '@app/common/modules/tag/repositories/tag-repository';
import { ProductRepository } from '@app/common/modules/product/repositories';
import { SpaceModelProductAllocationService } from 'src/space-model/services/space-model-product-allocation.service';
import { SubspaceModelProductAllocationService } from 'src/space-model/services/subspace/subspace-model-product-allocation.service';
import { DeviceService } from 'src/device/services';
import { SceneDeviceRepository } from '@app/common/modules/scene-device/repositories';
import { DeviceStatusFirebaseService } from '@app/common/firebase/devices-status/services/devices-status.service';
import { SceneService } from 'src/scene/services';
import { DeviceStatusLogRepository } from '@app/common/modules/device-status-log/repositories';
import {
  SceneIconRepository,
  SceneRepository,
} from '@app/common/modules/scene/repositories';
import { AutomationRepository } from '@app/common/modules/automation/repositories';
import {
  PowerClampHourlyRepository,
  PowerClampDailyRepository,
  PowerClampMonthlyRepository,
} from '@app/common/modules/power-clamp/repositories';
import { PowerClampService } from '@app/common/helper/services/power.clamp.service';
import { SqlLoaderService } from '@app/common/helper/services/sql-loader.service';
import { OccupancyService } from '@app/common/helper/services/occupancy.service';

@Module({
  imports: [ConfigModule, InviteUserRepositoryModule, CommunityModule],
  controllers: [InviteUserController],
  providers: [
    InviteUserService,
    InviteUserRepository,
    UserRepository,
    EmailService,
    InviteUserSpaceRepository,
    SpaceUserService,
    ValidationService,
    UserSpaceRepository,
    DeviceRepository,
    CommunityService,
    SpaceRepository,
    SpaceModelRepository,
    CommunityRepository,
    ProjectRepository,
    TuyaService,
    UserSpaceService,
    UserDevicePermissionService,
    DeviceUserPermissionRepository,
    PermissionTypeRepository,
    ProjectUserService,
    RoleTypeRepository,
    InviteSpaceRepository,
    UserService,
    RegionRepository,
    TimeZoneRepository,
    SpaceService,
    InviteSpaceRepository,
    SpaceLinkService,
    SubSpaceService,
    ValidationService,
    NewTagService,
    SpaceModelService,
    SpaceProductAllocationService,
    SpaceLinkRepository,
    SubspaceRepository,
    TagService,
    SubspaceDeviceService,
    SubspaceProductAllocationService,
    SpaceModelRepository,
    DeviceRepository,
    NewTagRepository,
    ProductRepository,
    SubSpaceModelService,
    SpaceModelProductAllocationService,
    SpaceProductAllocationRepository,
    SubspaceProductAllocationRepository,
    TagRepository,
    SubspaceModelRepository,
    SubspaceModelProductAllocationService,
    SpaceModelProductAllocationRepoitory,
    SubspaceModelProductAllocationRepoitory,
    DeviceService,
    SceneDeviceRepository,
    DeviceStatusFirebaseService,
    SceneService,
    DeviceStatusLogRepository,
    SceneIconRepository,
    SceneRepository,
    AutomationRepository,
    PowerClampService,
    PowerClampHourlyRepository,
    PowerClampDailyRepository,
    PowerClampMonthlyRepository,
    SqlLoaderService,
    OccupancyService,
  ],
  exports: [InviteUserService],
})
export class InviteUserModule {}
