import { ApiProperty, ApiPropertyOptional } from '@nestjs/swagger';
import { Type } from 'class-transformer';
import {
  IsString,
  IsOptional,
  IsArray,
  ValidateNested,
  IsEnum,
} from 'class-validator';
import { ModifyTagModelDto } from '../tag-model-dtos';
import { ModifyAction } from '@app/common/constants/modify-action.enum';

export class ModifySubspaceModelDto {
  @ApiProperty({
    description: 'Action to perform: add, update, or delete',
    example: ModifyAction.ADD,
  })
  @IsEnum(ModifyAction)
  action: ModifyAction;

  @ApiPropertyOptional({
    description: 'UUID of the subspace (required for update/delete)',
    example: '123e4567-e89b-12d3-a456-426614174000',
  })
  @IsOptional()
  @IsString()
  uuid?: string;

  @ApiPropertyOptional({
    description: 'Name of the subspace (required for add/update)',
    example: 'Living Room',
  })
  @IsOptional()
  @IsString()
  subspaceName?: string;

  @ApiPropertyOptional({
    description:
      'List of tag modifications (add/update/delete) for the subspace',
    type: [ModifyTagModelDto],
  })
  @IsOptional()
  @IsArray()
  @ValidateNested({ each: true })
  @Type(() => ModifyTagModelDto)
  tags?: ModifyTagModelDto[];
}
