import { ModifyAction } from '@app/common/constants/modify-action.enum';
import { ApiProperty, ApiPropertyOptional } from '@nestjs/swagger';
import { IsString, IsOptional, IsEnum, IsUUID } from 'class-validator';

export class ModifyTagModelDto {
  @ApiProperty({
    description: 'Action to perform: add, update, or delete',
    example: ModifyAction.ADD,
  })
  @IsEnum(ModifyAction)
  action: ModifyAction;

  @ApiPropertyOptional({
    description: 'UUID of the new tag',
    example: '123e4567-e89b-12d3-a456-426614174000',
  })
  @IsOptional()
  @IsUUID()
  newTagUuid: string;

  @ApiPropertyOptional({
    description:
      'UUID of an existing tag (required for update/delete, optional for add)',
    example: 'a1b2c3d4-5678-90ef-abcd-1234567890ef',
  })
  @IsOptional()
  @IsUUID()
  tagUuid?: string;

  @ApiPropertyOptional({
    description: 'Name of the tag (required for add/update)',
    example: 'Temperature Sensor',
  })
  @IsOptional()
  @IsString()
  name?: string;

  @ApiPropertyOptional({
    description:
      'UUID of the product associated with the tag (required for add)',
    example: 'c789a91e-549a-4753-9006-02f89e8170e0',
  })
  @IsOptional()
  @IsUUID()
  productUuid?: string;
}
