import { ApiProperty, ApiPropertyOptional } from '@nestjs/swagger';
import { IsArray, IsOptional, IsString, ValidateNested } from 'class-validator';
import { CreateSubspaceModelDto } from './subspaces-model-dtos/create-subspace-model.dto';
import { Type } from 'class-transformer';
import {
  DeleteSubspaceModelDto,
  ModifySubspaceModelDto,
  UpdateSubspaceModelDto,
} from './subspaces-model-dtos';
import { ModifyTagModelDto } from './tag-model-dtos';

export class ModifySubspacesModelDto {
  @ApiProperty({
    description: 'List of subspaces to add',
    type: [CreateSubspaceModelDto],
    required: false,
  })
  @IsOptional()
  @IsArray()
  @ValidateNested({ each: true })
  @Type(() => CreateSubspaceModelDto)
  add?: CreateSubspaceModelDto[];

  @ApiProperty({
    description: 'List of subspaces to add',
    type: [CreateSubspaceModelDto],
    required: false,
  })
  @IsOptional()
  @IsArray()
  @ValidateNested({ each: true })
  @Type(() => UpdateSubspaceModelDto)
  update?: UpdateSubspaceModelDto[];

  @ApiProperty({
    description: 'List of subspaces to delete',
    type: [DeleteSubspaceModelDto],
    required: false,
  })
  @IsOptional()
  @IsArray()
  @ValidateNested({ each: true })
  @Type(() => DeleteSubspaceModelDto)
  delete?: DeleteSubspaceModelDto[];
}

export class UpdateSpaceModelDto {
  @ApiProperty({
    description: 'Updated name of the space model',
    example: 'New Space Model Name',
  })
  @IsOptional()
  @IsString()
  modelName?: string;

  @ApiPropertyOptional({
    description: 'List of subspace modifications (add/update/delete)',
    type: [ModifySubspaceModelDto],
  })
  @IsOptional()
  @IsArray()
  @ValidateNested({ each: true })
  @Type(() => ModifySubspaceModelDto)
  subspaceModels?: ModifySubspaceModelDto[];

  @ApiPropertyOptional({
    description:
      'List of tag modifications (add/update/delete) for the space model',
    type: [ModifyTagModelDto],
  })
  @IsOptional()
  @IsArray()
  @ValidateNested({ each: true })
  @Type(() => ModifyTagModelDto)
  tags?: ModifyTagModelDto[];
}
